import * as i0 from '@angular/core';
import { computed, input, output, ChangeDetectionStrategy, Component } from '@angular/core';
import { LibsUiComponentsButtonsButtonComponent } from '@libs-ui/components-buttons-button';
import { LibsUiComponentsPopoverComponent } from '@libs-ui/components-popover';
import { LibsUiComponentsSwitchComponent } from '@libs-ui/components-switch';
import { viewDataNumberByLanguage } from '@libs-ui/utils';
import * as i1 from '@ngx-translate/core';
import { TranslateModule } from '@ngx-translate/core';

class LibsUiComponentsLabelComponent {
    // #region PROPERTY
    countDisplay = computed(() => `${viewDataNumberByLanguage(this.count() || 0, false)}`);
    maxLengthDisplay = computed(() => `${viewDataNumberByLanguage(this.limitLength() || 0, false)}`);
    // #region INPUT
    iconPopoverClass = input('libs-ui-icon-tooltip-outline', { transform: (value) => value || 'libs-ui-icon-tooltip-outline' });
    classInclude = input('libs-ui-label', { transform: (value) => `libs-ui-label ${value ?? ''}` });
    labelLeft = input();
    labelLeftClass = input('libs-ui-label-left-text libs-ui-font-h6m', { transform: (value) => `libs-ui-label-left-text libs-ui-font-h6m ${value ?? ''}` });
    labelLeftBehindToggleButton = input();
    popover = input();
    required = input();
    buttonsLeft = input([], { transform: (value) => value || [] });
    disableButtonsLeft = input();
    buttonsRight = input([], { transform: (value) => value || [] });
    disableButtonsRight = input();
    labelRight = input();
    labelRightClass = input('', { transform: (value) => value || '' });
    labelRightRequired = input();
    hasToggle = input();
    toggleSize = input('default', { transform: (value) => value || 'default' });
    toggleActive = input();
    toggleDisable = input();
    description = input();
    descriptionClass = input('libs-ui-label-description libs-ui-font-h7r', { transform: (value) => `libs-ui-label-description libs-ui-font-h5r ${value ?? ''}` });
    buttonsDescription = input([], { transform: (value) => value || [] });
    disableButtonsDescription = input();
    buttonsDescriptionContainerClass = input('flex libs-ui-label-description-button', { transform: value => value ?? 'flex libs-ui-label-description-button' });
    onlyShowCount = input();
    zIndexPopover = input(10, { transform: (value) => value ?? 10 });
    timerDestroyPopover = input(0, { transform: (value) => value ?? 0 });
    count = input(0, { transform: (value) => value || 0 });
    limitLength = input(0, { transform: (value) => value || 0 });
    // #region OUTPUT
    outClickButton = output();
    outSwitchEvent = output();
    outLabelRightClick = output();
    outLabelLeftClick = output();
    // #region FUNCTIONS
    async handlerClickButton(button) {
        if (button.action) {
            button.action(button);
        }
        this.outClickButton.emit(button);
    }
    async handlerSwitch(toggleEvent) {
        this.outSwitchEvent.emit(toggleEvent);
    }
    async handlerEventLabelRight(event) {
        if (event === 'click') {
            this.outLabelRightClick.emit(true);
        }
    }
    async handlerEventLabelLeft(event) {
        event.stopPropagation();
        this.outLabelLeftClick.emit(event);
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsLabelComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "18.2.13", type: LibsUiComponentsLabelComponent, isStandalone: true, selector: "libs_ui-components-label", inputs: { iconPopoverClass: { classPropertyName: "iconPopoverClass", publicName: "iconPopoverClass", isSignal: true, isRequired: false, transformFunction: null }, classInclude: { classPropertyName: "classInclude", publicName: "classInclude", isSignal: true, isRequired: false, transformFunction: null }, labelLeft: { classPropertyName: "labelLeft", publicName: "labelLeft", isSignal: true, isRequired: false, transformFunction: null }, labelLeftClass: { classPropertyName: "labelLeftClass", publicName: "labelLeftClass", isSignal: true, isRequired: false, transformFunction: null }, labelLeftBehindToggleButton: { classPropertyName: "labelLeftBehindToggleButton", publicName: "labelLeftBehindToggleButton", isSignal: true, isRequired: false, transformFunction: null }, popover: { classPropertyName: "popover", publicName: "popover", isSignal: true, isRequired: false, transformFunction: null }, required: { classPropertyName: "required", publicName: "required", isSignal: true, isRequired: false, transformFunction: null }, buttonsLeft: { classPropertyName: "buttonsLeft", publicName: "buttonsLeft", isSignal: true, isRequired: false, transformFunction: null }, disableButtonsLeft: { classPropertyName: "disableButtonsLeft", publicName: "disableButtonsLeft", isSignal: true, isRequired: false, transformFunction: null }, buttonsRight: { classPropertyName: "buttonsRight", publicName: "buttonsRight", isSignal: true, isRequired: false, transformFunction: null }, disableButtonsRight: { classPropertyName: "disableButtonsRight", publicName: "disableButtonsRight", isSignal: true, isRequired: false, transformFunction: null }, labelRight: { classPropertyName: "labelRight", publicName: "labelRight", isSignal: true, isRequired: false, transformFunction: null }, labelRightClass: { classPropertyName: "labelRightClass", publicName: "labelRightClass", isSignal: true, isRequired: false, transformFunction: null }, labelRightRequired: { classPropertyName: "labelRightRequired", publicName: "labelRightRequired", isSignal: true, isRequired: false, transformFunction: null }, hasToggle: { classPropertyName: "hasToggle", publicName: "hasToggle", isSignal: true, isRequired: false, transformFunction: null }, toggleSize: { classPropertyName: "toggleSize", publicName: "toggleSize", isSignal: true, isRequired: false, transformFunction: null }, toggleActive: { classPropertyName: "toggleActive", publicName: "toggleActive", isSignal: true, isRequired: false, transformFunction: null }, toggleDisable: { classPropertyName: "toggleDisable", publicName: "toggleDisable", isSignal: true, isRequired: false, transformFunction: null }, description: { classPropertyName: "description", publicName: "description", isSignal: true, isRequired: false, transformFunction: null }, descriptionClass: { classPropertyName: "descriptionClass", publicName: "descriptionClass", isSignal: true, isRequired: false, transformFunction: null }, buttonsDescription: { classPropertyName: "buttonsDescription", publicName: "buttonsDescription", isSignal: true, isRequired: false, transformFunction: null }, disableButtonsDescription: { classPropertyName: "disableButtonsDescription", publicName: "disableButtonsDescription", isSignal: true, isRequired: false, transformFunction: null }, buttonsDescriptionContainerClass: { classPropertyName: "buttonsDescriptionContainerClass", publicName: "buttonsDescriptionContainerClass", isSignal: true, isRequired: false, transformFunction: null }, onlyShowCount: { classPropertyName: "onlyShowCount", publicName: "onlyShowCount", isSignal: true, isRequired: false, transformFunction: null }, zIndexPopover: { classPropertyName: "zIndexPopover", publicName: "zIndexPopover", isSignal: true, isRequired: false, transformFunction: null }, timerDestroyPopover: { classPropertyName: "timerDestroyPopover", publicName: "timerDestroyPopover", isSignal: true, isRequired: false, transformFunction: null }, count: { classPropertyName: "count", publicName: "count", isSignal: true, isRequired: false, transformFunction: null }, limitLength: { classPropertyName: "limitLength", publicName: "limitLength", isSignal: true, isRequired: false, transformFunction: null } }, outputs: { outClickButton: "outClickButton", outSwitchEvent: "outSwitchEvent", outLabelRightClick: "outLabelRightClick", outLabelLeftClick: "outLabelLeftClick" }, ngImport: i0, template: "<div [class]=\"classInclude()\"\n  [class.mb-[4px]]=\"description()\"\n  [class.mb-[8px]]=\"!description()\">\n  <div class=\"libs-ui-label-left\"\n    [style.maxWidth.%]=\"(labelRight() || limitLength() || onlyShowCount()) ? 70:100\">\n    @if (hasToggle() && labelLeftBehindToggleButton()) {\n      <libs_ui-components-switch [size]=\"toggleSize()\"\n        [disable]=\"toggleDisable()\"\n        [class]=\"'mr-[8px]'\"\n        [active]=\"toggleActive() || false\"\n        (outSwitch)=\"handlerSwitch($event)\" />\n    }\n    @if (labelLeft()) {\n      <libs_ui-components-popover type=\"text\"\n        [config]=\"{zIndex: zIndexPopover(), timerDestroy: timerDestroyPopover()}\"\n        [innerHtml]=\"(labelLeft() || ' ') | translate\"\n        [classInclude]=\"labelLeftClass()\"\n        (click)=\"handlerEventLabelLeft($event)\" />\n    }\n    @if (required() && labelLeft()) {\n      <i class=\"flex libs-ui-icon-asterisk before:!text-[#ee2d41] before:!text-[8px] pb-[4px] h-full\"></i>\n    }\n    @if (popover()?.config && popover()?.config?.content) {\n      <libs_ui-components-popover classInclude=\"ml-[4px] {{ popover()?.classInclude }}\"\n        [config]=\"popover()?.config\">\n        <i [class]=\"iconPopoverClass()\"></i>\n      </libs_ui-components-popover>\n    }\n    @for (button of buttonsLeft(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [sizeButton]=\"button.sizeButton\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsLeft() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [popover]=\"button.popover || {}\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n    @if (hasToggle() && !labelLeftBehindToggleButton()) {\n      <libs_ui-components-switch [disable]=\"toggleDisable()\"\n        [size]=\"toggleSize()\"\n        [class]=\"'ml-[20px]'\"\n        [active]=\"toggleActive() || false\"\n        (outSwitch)=\"handlerSwitch($event)\" />\n    }\n  </div>\n\n  <div class=\"libs-ui-label-right\">\n    @if (labelRight(); as labelRight) {\n      <libs_ui-components-popover type=\"text\"\n        [innerHtml]=\"labelRight | translate\"\n        [classInclude]=\"labelRightClass()\"\n        (outEvent)=\"handlerEventLabelRight($event)\" />\n    }\n    @for (button of buttonsRight(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [sizeButton]=\"button.sizeButton\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsRight() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [classLabel]=\"button.classLabel || ''\"\n        [popover]=\"button.popover || {}\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n    @if (limitLength() || onlyShowCount()) {\n      <div class=\"flex items-center ml-[12px] text-[#9ca2ad] libs-ui-font-h7r\">\n        <span>{{ countDisplay() }}</span>\n        @if (limitLength()) {\n          <span>\n            /{{ maxLengthDisplay() }}\n          </span>\n          }\n          <span>&nbsp;{{ 'i18n_character' | translate }}</span>\n      </div>\n      }\n  </div>\n</div>\n@if (description(); as description) {\n  <div [class]=\"descriptionClass()\"\n    [innerHtml]='description | translate '></div>\n}\n@if (buttonsDescription()?.length) {\n  <div [class]=\"buttonsDescriptionContainerClass()\">\n    @for (button of buttonsDescription(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsDescription() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [popover]=\"button.popover || {}\"\n        [classLabel]=\"button.classLabel || ''\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n  </div>\n}\n<ng-content select=\"div.libs-ui-custom-description\" />\n", styles: [".libs-ui-label{display:flex;justify-content:space-between;width:100%}.libs-ui-label .libs-ui-label-left{display:flex;align-items:center}.libs-ui-label .libs-ui-label-left .libs-ui-label-left-text{color:#6a7383}.libs-ui-label .libs-ui-label-left libs_ui-components-button{margin-left:12px}.libs-ui-label .libs-ui-label-left .libs-ui-label-left-optional{margin-left:0;font-size:10px!important;color:#9ca2ad;line-height:15px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.libs-ui-label .libs-ui-label-right{display:flex;align-items:center;justify-content:flex-end}.libs-ui-label .libs-ui-label-right libs_ui-components-button{margin-left:12px}.libs-ui-label-description{color:#9ca2ad;margin-bottom:8px}.libs-ui-label-description-button{margin-bottom:4px}\n"], dependencies: [{ kind: "ngmodule", type: TranslateModule }, { kind: "pipe", type: i1.TranslatePipe, name: "translate" }, { kind: "component", type: LibsUiComponentsPopoverComponent, selector: "libs_ui-components-popover,[LibsUiComponentsPopoverDirective]", inputs: ["debugId", "flagMouse", "type", "mode", "config", "ignoreShowPopover", "elementRefCustom", "initEventInElementRefCustom", "classInclude", "ignoreHiddenPopoverContentWhenMouseLeave", "ignoreStopPropagationEvent", "ignoreCursorPointerModeLikeClick", "isAddContentToParentDocument", "ignoreClickOutside"], outputs: ["outEvent", "outChangStageFlagMouse", "outEventPopoverContent", "outFunctionsControl"] }, { kind: "component", type: LibsUiComponentsButtonsButtonComponent, selector: "libs_ui-components-buttons-button", inputs: ["flagMouse", "type", "buttonCustom", "sizeButton", "label", "disable", "isPending", "imageLeft", "classInclude", "classIconLeft", "classIconRight", "classLabel", "iconOnlyType", "popover", "ignoreStopPropagationEvent", "zIndex", "widthLabelPopover", "styleIconLeft", "styleButton", "ignoreFocusWhenInputTab", "ignoreSetClickWhenShowPopover", "ignorePointerEvent", "isActive", "isHandlerEnterDocumentClickButton"], outputs: ["outClick", "outPopoverEvent", "outFunctionsControl"] }, { kind: "component", type: LibsUiComponentsSwitchComponent, selector: "libs_ui-components-switch", inputs: ["size", "disable", "active"], outputs: ["activeChange", "outSwitch"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "18.2.13", ngImport: i0, type: LibsUiComponentsLabelComponent, decorators: [{
            type: Component,
            args: [{ selector: 'libs_ui-components-label', standalone: true, imports: [
                        TranslateModule,
                        LibsUiComponentsPopoverComponent,
                        LibsUiComponentsButtonsButtonComponent,
                        LibsUiComponentsSwitchComponent
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div [class]=\"classInclude()\"\n  [class.mb-[4px]]=\"description()\"\n  [class.mb-[8px]]=\"!description()\">\n  <div class=\"libs-ui-label-left\"\n    [style.maxWidth.%]=\"(labelRight() || limitLength() || onlyShowCount()) ? 70:100\">\n    @if (hasToggle() && labelLeftBehindToggleButton()) {\n      <libs_ui-components-switch [size]=\"toggleSize()\"\n        [disable]=\"toggleDisable()\"\n        [class]=\"'mr-[8px]'\"\n        [active]=\"toggleActive() || false\"\n        (outSwitch)=\"handlerSwitch($event)\" />\n    }\n    @if (labelLeft()) {\n      <libs_ui-components-popover type=\"text\"\n        [config]=\"{zIndex: zIndexPopover(), timerDestroy: timerDestroyPopover()}\"\n        [innerHtml]=\"(labelLeft() || ' ') | translate\"\n        [classInclude]=\"labelLeftClass()\"\n        (click)=\"handlerEventLabelLeft($event)\" />\n    }\n    @if (required() && labelLeft()) {\n      <i class=\"flex libs-ui-icon-asterisk before:!text-[#ee2d41] before:!text-[8px] pb-[4px] h-full\"></i>\n    }\n    @if (popover()?.config && popover()?.config?.content) {\n      <libs_ui-components-popover classInclude=\"ml-[4px] {{ popover()?.classInclude }}\"\n        [config]=\"popover()?.config\">\n        <i [class]=\"iconPopoverClass()\"></i>\n      </libs_ui-components-popover>\n    }\n    @for (button of buttonsLeft(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [sizeButton]=\"button.sizeButton\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsLeft() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [popover]=\"button.popover || {}\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n    @if (hasToggle() && !labelLeftBehindToggleButton()) {\n      <libs_ui-components-switch [disable]=\"toggleDisable()\"\n        [size]=\"toggleSize()\"\n        [class]=\"'ml-[20px]'\"\n        [active]=\"toggleActive() || false\"\n        (outSwitch)=\"handlerSwitch($event)\" />\n    }\n  </div>\n\n  <div class=\"libs-ui-label-right\">\n    @if (labelRight(); as labelRight) {\n      <libs_ui-components-popover type=\"text\"\n        [innerHtml]=\"labelRight | translate\"\n        [classInclude]=\"labelRightClass()\"\n        (outEvent)=\"handlerEventLabelRight($event)\" />\n    }\n    @for (button of buttonsRight(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [sizeButton]=\"button.sizeButton\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsRight() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [classLabel]=\"button.classLabel || ''\"\n        [popover]=\"button.popover || {}\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n    @if (limitLength() || onlyShowCount()) {\n      <div class=\"flex items-center ml-[12px] text-[#9ca2ad] libs-ui-font-h7r\">\n        <span>{{ countDisplay() }}</span>\n        @if (limitLength()) {\n          <span>\n            /{{ maxLengthDisplay() }}\n          </span>\n          }\n          <span>&nbsp;{{ 'i18n_character' | translate }}</span>\n      </div>\n      }\n  </div>\n</div>\n@if (description(); as description) {\n  <div [class]=\"descriptionClass()\"\n    [innerHtml]='description | translate '></div>\n}\n@if (buttonsDescription()?.length) {\n  <div [class]=\"buttonsDescriptionContainerClass()\">\n    @for (button of buttonsDescription(); track button) {\n      <libs_ui-components-buttons-button [type]=\"(button.type ||'button-link-primary')\"\n        [label]=\"button.label || ' '\"\n        [disable]=\"button.disable || disableButtonsDescription() || false\"\n        [classIconLeft]=\"button.classIconLeft || ''\"\n        [classInclude]=\"button.classInclude || ''\"\n        [classIconRight]=\"button.classIconRight || ''\"\n        [popover]=\"button.popover || {}\"\n        [classLabel]=\"button.classLabel || ''\"\n        (outClick)=\"handlerClickButton(button)\" />\n    }\n  </div>\n}\n<ng-content select=\"div.libs-ui-custom-description\" />\n", styles: [".libs-ui-label{display:flex;justify-content:space-between;width:100%}.libs-ui-label .libs-ui-label-left{display:flex;align-items:center}.libs-ui-label .libs-ui-label-left .libs-ui-label-left-text{color:#6a7383}.libs-ui-label .libs-ui-label-left libs_ui-components-button{margin-left:12px}.libs-ui-label .libs-ui-label-left .libs-ui-label-left-optional{margin-left:0;font-size:10px!important;color:#9ca2ad;line-height:15px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.libs-ui-label .libs-ui-label-right{display:flex;align-items:center;justify-content:flex-end}.libs-ui-label .libs-ui-label-right libs_ui-components-button{margin-left:12px}.libs-ui-label-description{color:#9ca2ad;margin-bottom:8px}.libs-ui-label-description-button{margin-bottom:4px}\n"] }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { LibsUiComponentsLabelComponent };
//# sourceMappingURL=libs-ui-components-label.mjs.map
